@@ -13,7 +13,6 @@ from CRTK.utilities import get_function_signatures_list, check_ERC_standard, get
 class RuntimeContract(Contract):
     def __init__(self, bytecode, address=''):
         super(RuntimeContract, self).__init__()
-        self.runtime_contract = True
 
         if bytecode[:2] == '0x' or bytecode[:2] == '0X':
             self.bytecode = bytecode[2:].lower()
@@ -40,3 +39,6 @@ class RuntimeContract(Contract):
         if check_ERC_standard(self.function_signatures, standard='ERC777'):
             self.ERC777 = True
 
+    def is_runtime_contract(self):
+        return True
+
